# &#128013; Create Powerful Data Apps in Python with Panel

It's a **super power** for you and your team to master a data app framework!

With [Panel](https://panel.holoviz.org) you can easily create data apps in Python **using the tools you know and love &#10084;&#65039;**.

**Check out the resources in the sidebar for inspiration**.

<div align="center" style="margin-right:10%;margin-left:10%; height: 450px" >
    <a href="volume_profile_analysis"><video autoplay loop muted style="height:450px;width:100%">
    <source src="https://cdn.jsdelivr.net/gh/awesome-panel/awesome-panel-assets@b5d85471f3e0ae5cac37635f621f68180cbb04fc/awesome-panel/applications/volume_profile_analysis.mp4" type="video/mp4">
</video></a>
</div>

## &#128106; Panel is for You

The only way to truly understand if Panel is something for you is to play around with it. You can

- Get started with Panel using the [Panel Getting Started Guide](http://panel.pyviz.org/getting_started/index.html). If you have questions reach out on [Discourse](https://discourse.holoviz.org/).

- Play around with the [awesome-panel.org](https://awesome-panel.org) apps on your own laptop as simple as

```bash
pip install awesome-panel[examples]
pn hello awesome-panel
```

- Sit back and watch my video from PyData Global for further inspiration

<div align="center" style="margin-right:10%;margin-left:10%;">
    <iframe src="https://www.youtube.com/embed/0DBEXiMdSKc" frameborder="0" allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture" allowfullscreen style="width:100%;height:400px;margin-left: auto;margin-right:auto"></iframe>
</div>

## &#128394;&#65039; Panel is for me

Check out why I prefer to use Panel for my data apps in the [blog post](https://medium.com/@marcskovmadsen/i-prefer-to-use-panel-for-my-data-apps-here-is-why-1ff5d2b98e8f).

<div align="center" style="margin-right:10%;margin-left:10%;">
    <a class="reference external" href="https://medium.com/@marcskovmadsen/i-prefer-to-use-panel-for-my-data-apps-here-is-why-1ff5d2b98e8f" target="_blank"><img alt="Blog Pos" src="https://cdn.jsdelivr.net/gh/awesome-panel/awesome-panel-assets@2a2206da65e1e88effda599c30230d2a5b130bca/images/i-prefer-panel.png" style="height:250px"></a>
</div>